@@ -479,68 +479,68 @@ namespace gnote {
   {
     std::vector<NoteBase::Ref> linking_notes(manager().get_notes_linking_to(old_title));
 
+    auto end_rename = [this, old_title] {
+      signal_renamed(*this, old_title);
+      queue_save(CONTENT_CHANGED);
+    };
+
     if (!linking_notes.empty()) {
       const NoteRenameBehavior behavior = static_cast<NoteRenameBehavior>(m_gnote.preferences().note_rename_behavior());
 
+      auto process_rename_link_update_end = [this, old_title](NoteRenameDialog::Response response, NoteRenameDialog &dialog) {
+        const NoteRenameBehavior selected_behavior = dialog.get_selected_behavior();
+        if(NoteRenameDialog::Response::CANCEL != response && NOTE_RENAME_ALWAYS_SHOW_DIALOG != selected_behavior) {
+          m_gnote.preferences().note_rename_behavior(selected_behavior);
+        }
+
+        const auto notes = dialog.get_notes();
+
+        for(const auto & item : notes) {
+          bool rename = item.second && response == NoteRenameDialog::Response::RENAME;
+          manager().find_by_uri(item.first, [this, rename, &old_title](NoteBase & note) {
+            if(rename) {
+              note.rename_links(old_title, *this);
+            }
+            else {
+              note.remove_links(old_title, *this);
+            }
+          });
+        }
+        get_window()->editor()->set_editable(true);
+        // must be at the end, because closing causes reponse with cancel
+        dialog.close();
+      };
+
       if (NOTE_RENAME_ALWAYS_SHOW_DIALOG == behavior) {
-        NoteRenameDialog *dlg = new NoteRenameDialog(linking_notes, old_title, *this, m_gnote);
-        dlg->signal_response().connect([this, dlg, old_title, self_uri=uri()](int response) {
-          manager().find_by_uri(self_uri, [this, response, dlg, old_title](NoteBase & note) {
-            process_rename_link_update_end(response, dlg, old_title, static_cast<Note&>(note));
+        auto &dlg = *manage(new NoteRenameDialog(linking_notes, old_title, *this, m_gnote));
+        dlg.signal_response.connect([this, &dlg, process_rename_link_update_end, end_rename, self_uri=uri()](NoteRenameDialog::Response response) {
+          // ensure captured this is still valid
+          manager().find_by_uri(self_uri, [this, response, &dlg, process_rename_link_update_end, end_rename](NoteBase & note) {
+            process_rename_link_update_end(response, dlg);
+            end_rename();
           });
         });
-        dlg->present();
+        dlg.present();
         get_window()->editor()->set_editable(false);
       }
       else if (NOTE_RENAME_ALWAYS_REMOVE_LINKS == behavior) {
         for(NoteBase & note : linking_notes) {
           note.remove_links(old_title, *this);
-          process_rename_link_update_end(Gtk::ResponseType::NO, NULL, old_title, *this);
         }
+        end_rename();
       }
       else if (NOTE_RENAME_ALWAYS_RENAME_LINKS == behavior) {
         for(NoteBase & note : linking_notes) {
           note.rename_links(old_title, *this);
-          process_rename_link_update_end(Gtk::ResponseType::NO, NULL, old_title, *this);
         }
+        end_rename();
       }
     }
     else {
-      signal_renamed(*this, old_title);
-      queue_save(CONTENT_CHANGED);
+      end_rename();
     }
   }
 
-  void Note::process_rename_link_update_end(int response, Gtk::Dialog *dialog,
-                                            const Glib::ustring & old_title, const Note & self)
-  {
-    if(auto dlg = dynamic_cast<NoteRenameDialog*>(dialog)) {
-      const NoteRenameBehavior selected_behavior = dlg->get_selected_behavior();
-      if(Gtk::ResponseType::CANCEL != response && NOTE_RENAME_ALWAYS_SHOW_DIALOG != selected_behavior) {
-        m_gnote.preferences().note_rename_behavior(selected_behavior);
-      }
-
-      const auto notes = dlg->get_notes();
-      delete dialog;
-
-      for(const auto & item : notes) {
-        bool rename = item.second && response == Gtk::ResponseType::YES;
-        manager().find_by_uri(item.first, [this, rename, &old_title, &self](NoteBase & note) {
-          if(rename) {
-            note.rename_links(old_title, *this);
-          }
-          else {
-            note.remove_links(old_title, self);
-          }
-        });
-      }
-      get_window()->editor()->set_editable(true);
-    }
-
-    signal_renamed(*this, old_title);
-    queue_save(CONTENT_CHANGED);
-  }
-
 
   bool Note::contains_text(const Glib::ustring & text)
   {
