@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017,2019-2020,2022 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019-2020,2022-2023 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -37,8 +37,6 @@ namespace gnote {
     : public NoteManagerBase
   {
   public:
-    typedef sigc::slot<void(const Note::Ptr &)> NoteChangedSlot;
-    
     NoteManager(IGnote & g);
     virtual ~NoteManager();
 
@@ -66,7 +64,10 @@ namespace gnote {
         return *m_addin_mgr;
       }
 
-    virtual NoteBase::Ptr get_or_create_template_note() override;
+    Note & get_or_create_template_note() override;
+
+    void queue_save(NoteBase & note);
+    void save_notes();
 
     ChangedHandler signal_note_buffer_changed;
 
@@ -74,9 +75,9 @@ namespace gnote {
   protected:
     virtual void post_load() override;
     virtual void migrate_notes(const Glib::ustring & old_note_dir) override;
-    NoteBase::Ptr create_note_from_template(Glib::ustring && title, const NoteBase::Ptr & template_note, Glib::ustring && guid) override;
-    NoteBase::Ptr create_note(Glib::ustring && title, Glib::ustring && body, Glib::ustring && guid = Glib::ustring()) override;
-    NoteBase::Ptr create_new_note(Glib::ustring && title, Glib::ustring && xml_content, Glib::ustring && guid) override;
+    Note & create_note_from_template(Glib::ustring && title, const NoteBase & template_note, Glib::ustring && guid) override;
+    Note & create_note(Glib::ustring && title, Glib::ustring && body, Glib::ustring && guid = Glib::ustring()) override;
+    Note & create_new_note(Glib::ustring && title, Glib::ustring && xml_content, Glib::ustring && guid) override;
     virtual NoteBase::Ptr note_create_new(Glib::ustring && title, Glib::ustring && file_name) override;
     NoteBase::Ptr note_load(Glib::ustring && file_name) override;
   private:
@@ -90,6 +91,10 @@ namespace gnote {
     AddinManager   *m_addin_mgr;
     NoteArchiver m_note_archiver;
     TagManager m_tag_manager;
+
+    // Notes to save, URIs
+    std::vector<Glib::ustring> m_queued_saves;
+    guint m_save_timeout;
   };
 
 
