@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2017,2019,2021-2023 Aurimas Cernius
+ * Copyright (C) 2011-2017,2019,2021-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -49,7 +49,7 @@ class NoteTextMenu
   : public Gtk::Popover
 {
 public:
-  NoteTextMenu(EmbeddableWidget & widget, const Glib::RefPtr<NoteBuffer> & buffer);
+  NoteTextMenu(EmbeddableWidget & widget, const Glib::RefPtr<NoteBuffer> & buffer, Preferences &prefs);
 private:
   void refresh_state(EmbeddableWidget & widget, const Glib::RefPtr<NoteBuffer> & buffer);
   void refresh_sizing_state(EmbeddableWidget & widget, const Glib::RefPtr<NoteBuffer> & buffer);
@@ -150,7 +150,7 @@ private:
   void on_untemplate_button_click();
   void on_save_selection_check_button_toggled();
   void on_save_title_check_button_toggled();
-  void on_note_tag_added(const NoteBase&, const Tag::Ptr&);
+  void on_note_tag_added(const NoteBase&, const Tag&);
   void on_note_tag_removed(const NoteBase&, const Glib::ustring&);
   void link_button_clicked();
   bool open_help_activate(Gtk::Widget&, const Glib::VariantBase&);
@@ -175,6 +175,8 @@ private:
   bool increase_font_clicked(Gtk::Widget&, const Glib::VariantBase&);
   bool decrease_font_clicked(Gtk::Widget&, const Glib::VariantBase&);
   void undo_changed();
+  Tag &template_save_selection_tag();
+  Tag &template_save_title_tag();
 
   Note                        & m_note;
   IGnote                      & m_gnote;
@@ -192,9 +194,9 @@ private:
   std::vector<sigc::connection> m_signal_cids;
   bool                         m_enabled;
 
-  Tag::Ptr m_template_tag;
-  Tag::Ptr m_template_save_selection_tag;
-  Tag::Ptr m_template_save_title_tag;
+  Glib::ustring m_template_tag;
+  Glib::ustring m_template_save_selection_tag;
+  Glib::ustring m_template_save_title_tag;
 };
 
 
