@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2013,2015-2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2011-2013,2015-2017,2019-2020,2022-2023 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -27,14 +27,10 @@
 #include <map>
 
 #include <gtkmm/dialog.h>
-#include <gtkmm/treeiter.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/combobox.h>
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/radiobutton.h>
+#include <gtkmm/dropdown.h>
 #include <gtkmm/spinbutton.h>
 
-#include "sharp/addinstreemodel.hpp"
+#include "sharp/pluginsmodel.hpp"
 
 namespace gnote {
 
@@ -71,7 +67,7 @@ private:
   void on_advanced_sync_config_button();
   void on_reset_sync_addin_button(bool signal);
   void on_save_sync_addin_button();
-  void on_sync_settings_saved(bool saved, Glib::ustring errorMsg);
+  void on_sync_settings_saved(const Glib::RefPtr<Glib::Object> & active_sync_service, bool saved, Glib::ustring errorMsg);
 
   void on_note_rename_behavior_changed();
   void on_autosync_timeout_setting_changed();
@@ -79,41 +75,23 @@ private:
 
   Glib::ustring get_selected_addin();
   void set_module_for_selected_addin(sharp::DynamicModule * module);
-  void on_addin_tree_selection_changed();
+  void on_plugin_view_selection_changed(const Glib::RefPtr<sharp::Plugin> & plugin);
   void update_addin_buttons();
+  void update_addin_buttons(const Glib::RefPtr<sharp::Plugin> & plugin);
   void load_addins();
   void on_enable_addin_button();
   void on_disable_addin_button();
   void on_addin_prefs_button();
-  bool addin_pref_dialog_deleted(GdkEventAny*, Gtk::Dialog*);
-  void addin_pref_dialog_response(int, Gtk::Dialog*);
+  void addin_pref_dialog_response(const Glib::ustring &, Gtk::Dialog*);
   void on_addin_info_button();
-  bool addin_info_dialog_deleted(GdkEventAny*, Gtk::Dialog*);
   void addin_info_dialog_response(int, Gtk::Dialog*);
   void on_sync_addin_prefs_changed();
-  void on_conflict_option_toggle();
-  void combo_box_text_data_func(const Gtk::TreeIter & iter);
   void update_sync_services();
   void update_timeout_pref();
   void on_autosync_check_toggled();
 ////
 
-  class SyncStoreModel
-    : public Gtk::TreeModelColumnRecord
-  {
-  public:
-    SyncStoreModel()
-      {
-        add(m_col1);
-      }
-
-    Gtk::TreeModelColumn<sync::SyncServiceAddin*> m_col1;
-  };
-
-  SyncStoreModel m_sync_addin_store_record;
-  Glib::RefPtr<Gtk::ListStore> m_sync_addin_store;
-  std::map<Glib::ustring, Gtk::TreeIter> m_sync_addin_iters;
-  Gtk::ComboBox *m_sync_addin_combo;
+  Gtk::DropDown *m_sync_addin_combo;
   sync::SyncServiceAddin *m_selected_sync_addin;
   Gtk::Grid   *m_sync_addin_prefs_container;
   Gtk::Widget *m_sync_addin_prefs_widget;
@@ -121,7 +99,7 @@ private:
   Gtk::Button *m_save_sync_addin_button;
   Gtk::CheckButton *m_autosync_check;
   Gtk::SpinButton *m_autosync_spinner;
-  Gtk::ComboBoxText *m_rename_behavior_combo;
+  Gtk::DropDown *m_rename_behavior_combo;
   IGnote & m_gnote;
   AddinManager &m_addin_manager;
   NoteManager & m_note_manager;
@@ -130,20 +108,14 @@ private:
   Gtk::Label  *font_face;
   Gtk::Label  *font_size;
 
-  Gtk::TreeView              *m_addin_tree;
-  sharp::AddinsTreeModel::Ptr m_addin_tree_model;
+  Gtk::ColumnView *m_plugin_view;
+  sharp::AddinsModel::Ptr m_plugin_model;
   
   Gtk::Button *enable_addin_button;
   Gtk::Button *disable_addin_button;
   Gtk::Button *addin_prefs_button;
   Gtk::Button *addin_info_button;
 
-  Gtk::RadioButton::Group conflictRadioGroup;
-  Gtk::RadioButton *promptOnConflictRadio;
-  Gtk::RadioButton *renameOnConflictRadio;
-  Gtk::RadioButton *overwriteOnConflictRadio;
-
-
   /// Keep track of the opened addin prefs dialogs so other windows
   /// can be interacted with (as opposed to opening these as modal
   /// dialogs).
