@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013,2017-2023 Aurimas Cernius
+ * Copyright (C) 2012-2013,2017-2023,2025 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 
 
 #include <algorithm>
-#include <condition_variable>
 #include <stdexcept>
 
 #include <glibmm/i18n.h>
@@ -27,6 +26,7 @@
 
 #include "debug.hpp"
 #include "filesystemsyncserver.hpp"
+#include "gvfstransfer.hpp"
 #include "preferences.hpp"
 #include "sharp/directory.hpp"
 #include "sharp/files.hpp"
@@ -48,6 +48,60 @@ int str_to_int(const Glib::ustring & s)
   }
 }
 
+struct NoteUpload
+  : gnote::sync::FileTransfer
+{
+  NoteUpload(const Glib::RefPtr<Gio::File> &src, const Glib::RefPtr<Gio::File> &dest, Glib::ustring &&result_path)
+    : FileTransfer(src, dest)
+    , result_path(std::move(result_path))
+  {}
+
+  const Glib::ustring result_path;
+};
+
+struct NoteDownload
+  : gnote::sync::FileTransfer
+{
+  explicit NoteDownload(const Glib::ustring &note_id)
+    : FileTransfer({}, {})
+    , revision(-1)
+    , note_id(note_id)
+  {}
+
+  NoteDownload(const Glib::RefPtr<Gio::File> &src, const Glib::RefPtr<Gio::File> &dest, int revision, Glib::ustring &&note_id, Glib::ustring &&result_path)
+    : FileTransfer(src, dest)
+    , revision(revision)
+    , note_id(std::move(note_id))
+    , result_path(std::move(result_path))
+  {}
+
+  const int revision;
+  const Glib::ustring note_id;
+  const Glib::ustring result_path;
+};
+
+class NoteDownloadHash
+{
+public:
+  std::size_t operator()(const NoteDownload & d) const noexcept
+  {
+    return m_hash(d.note_id);
+  }
+private:
+  gnote::Hash<Glib::ustring> m_hash;
+};
+
+class NoteDownloadIdEqual
+{
+public:
+  bool operator()(const NoteDownload &x, const NoteDownload &y) const noexcept
+  {
+    return x.note_id == y.note_id;
+  }
+};
+
+typedef std::unordered_set<NoteDownload, NoteDownloadHash, NoteDownloadIdEqual> NoteDownloadSet;
+
 }
 
 
@@ -99,49 +153,24 @@ void FileSystemSyncServer::upload_notes(const std::vector<NoteBase::Ref> & notes
   mkdir_p(m_new_revision_path);
   DBG_OUT("UploadNotes: notes.Count = %d", int(notes.size()));
   m_updated_notes.reserve(notes.size());
-  std::mutex notes_lock;
-  std::condition_variable all_uploaded;
-  auto cancel_op = Gio::Cancellable::create();
-  unsigned failures = 0;
-  unsigned total = notes.size();
-  for(const NoteBase & iter : notes) {
+  std::vector<NoteUpload> uploads;
+  for(NoteBase &iter : notes) {
     auto file_path = iter.file_path();
-    auto server_note = m_new_revision_path->get_child(sharp::file_filename(file_path));
     auto local_note = Gio::File::create_for_path(file_path);
-    local_note->copy_async(server_note, [this, &notes_lock, &all_uploaded, &total, &failures, local_note, file_path = std::move(file_path)]
-                                        (Glib::RefPtr<Gio::AsyncResult> & result) {
-      try {
-        if(local_note->copy_finish(result)) {
-          auto path = sharp::file_basename(file_path);
-          std::unique_lock<std::mutex> lock(notes_lock);
-          m_updated_notes.emplace_back(std::move(path));
-          if(--total == 0) {
-            all_uploaded.notify_one();
-          }
-          return;
-        }
-      }
-      catch (std::exception & e) {
-        ERR_OUT(_("Failed to upload note: %s"), e.what());
-      }
-
-      std::unique_lock<std::mutex> lock(notes_lock);
-      ++failures;
-      --total;
-      all_uploaded.notify_one();
-    }, cancel_op);
+    auto server_note = m_new_revision_path->get_child(sharp::file_filename(file_path));
+    uploads.emplace_back(local_note, server_note, sharp::file_basename(file_path));
   }
 
-  std::unique_lock<std::mutex> lock(notes_lock);
-  while(total > 0) {
-    all_uploaded.wait(lock);
-    if(failures > 0) {
-      cancel_op->cancel();
-    }
-  }
+  GvfsTransfer file_transfer(uploads);
+  const auto failures = file_transfer.transfer();
   if(failures > 0) {
     throw GnoteSyncException(Glib::ustring::compose(ngettext("Failed to upload %1 note", "Failed to upload %1 notes", failures), failures));
   }
+  else {
+    for(auto &upload : uploads) {
+      m_updated_notes.emplace_back(std::move(upload.result_path));
+    }
+  }
 }
 
 
@@ -176,21 +205,18 @@ bool FileSystemSyncServer::updates_available_since(int revision)
 }
 
 
-std::map<Glib::ustring, NoteUpdate> FileSystemSyncServer::get_note_updates_since(int revision)
+SyncServer::NoteUpdatesMap FileSystemSyncServer::get_note_updates_since(int revision)
 {
-  std::mutex note_updates_lock;
-  std::condition_variable note_updates_done;
-  std::map<Glib::ustring, NoteUpdate> noteUpdates;
-  unsigned failures = 0;
+  SyncServer::NoteUpdatesMap noteUpdates;
 
-  Glib::ustring tempPath = Glib::build_filename(m_cache_path, "sync_temp");
-  if(!sharp::directory_exists(tempPath)) {
-    sharp::directory_create(tempPath);
+  Glib::ustring temp_path = Glib::build_filename(m_cache_path, "sync_temp");
+  if(!sharp::directory_exists(temp_path)) {
+    sharp::directory_create(temp_path);
   }
   else {
     // Empty the temp dir
     try {
-      std::vector<Glib::ustring> files = sharp::directory_get_files(tempPath);
+      std::vector<Glib::ustring> files = sharp::directory_get_files(temp_path);
       for(auto & iter : files) {
         sharp::file_delete(iter);
       }
@@ -198,6 +224,7 @@ std::map<Glib::ustring, NoteUpdate> FileSystemSyncServer::get_note_updates_since
     catch(...) {}
   }
 
+  NoteDownloadSet downloads;
   xmlDocPtr xml_doc = NULL;
   if(is_valid_xml_file(m_manifest_path, &xml_doc)) {
     xmlNodePtr root_node = xmlDocGetRootElement(xml_doc);
@@ -206,62 +233,36 @@ std::map<Glib::ustring, NoteUpdate> FileSystemSyncServer::get_note_updates_since
     sharp::XmlNodeSet noteNodes = sharp::xml_node_xpath_find(root_node, xpath.c_str());
     DBG_OUT("get_note_updates_since xpath returned %d nodes", int(noteNodes.size()));
     if(noteNodes.size() > 0) {
-      auto cancel_op = Gio::Cancellable::create();
       for(auto & node : noteNodes) {
         Glib::ustring note_id = sharp::xml_node_content(sharp::xml_node_xpath_find_single_node(node, "@id"));
         int rev = str_to_int(sharp::xml_node_content(sharp::xml_node_xpath_find_single_node(node, "@rev")));
-        if(noteUpdates.find(note_id) == noteUpdates.end()) {
+        if(downloads.find(NoteDownload(note_id)) == downloads.end()) {
+          auto rev_dir = get_revision_dir_path(rev);
+          auto server_note = rev_dir->get_child(note_id + ".note");
           // Copy the file from the server to the temp directory
-          auto revDir = get_revision_dir_path(rev);
-          auto serverNotePath = revDir->get_child(note_id + ".note");
-          Glib::ustring noteTempPath = Glib::build_filename(tempPath, note_id + ".note");
-          auto dest = Gio::File::create_for_path(noteTempPath);
-          serverNotePath->copy_async(dest,
-            [serverNotePath, &note_updates_lock, &note_updates_done, &noteUpdates, &failures, noteTempPath = std::move(noteTempPath), note_id = std::move(note_id), rev, total = noteNodes.size()]
-            (Glib::RefPtr<Gio::AsyncResult> & result) {
-              try {
-                if(serverNotePath->copy_finish(result)) {
-                  // Get the title, contents, etc.
-                  Glib::ustring noteTitle;
-                  Glib::ustring noteXml = sharp::file_read_all_text(noteTempPath);
-                  NoteUpdate update(noteXml, noteTitle, note_id, rev);
-                  std::unique_lock<std::mutex> lock(note_updates_lock);
-                  noteUpdates.insert(std::make_pair(note_id, update));
-                  if(noteUpdates.size() + failures >= total) {
-                    note_updates_done.notify_one();
-                  }
-                  return; // all done, error handling below
-                }
-              }
-              catch(std::exception & e) {
-                ERR_OUT(_("Exception when finishing note copy: %s"), e.what());
-              }
-              catch(...) {
-                ERR_OUT(_("Exception when finishing note copy"));
-              }
-
-              std::unique_lock<std::mutex> lock(note_updates_lock);
-              ++failures;
-              note_updates_done.notify_one();
-            }, cancel_op);
+          Glib::ustring note_temp_path = Glib::build_filename(temp_path, note_id + ".note");
+          auto dest = Gio::File::create_for_path(note_temp_path);
+          downloads.emplace(server_note, dest, rev, std::move(note_id), std::move(note_temp_path));
         }
       }
-
-      std::unique_lock<std::mutex> lock(note_updates_lock);
-      while(noteUpdates.size() + failures < noteNodes.size()) {
-        if(failures > 0 && !cancel_op->is_cancelled()) {
-          cancel_op->cancel();
-        }
-        note_updates_done.wait(lock);
-      }
     }
 
     xmlFreeDoc(xml_doc);
   }
 
+  GvfsTransfer file_transfers(downloads);
+  const auto failures = file_transfers.transfer();
+
   if(failures > 0) {
     throw GnoteSyncException(Glib::ustring::compose(ngettext("Failed to download %1 note update", "Failed to download %1 note updates", failures), failures));
   }
+
+  for(const auto &downloaded : downloads) {
+    Glib::ustring note_xml = sharp::file_read_all_text(downloaded.result_path);
+    NoteUpdate update(note_xml, Glib::ustring(), downloaded.note_id, downloaded.revision);
+    noteUpdates.insert(std::make_pair(downloaded.note_id, update));
+  }
+
   DBG_OUT("get_note_updates_since (%d) returning: %d", revision, int(noteUpdates.size()));
   return noteUpdates;
 }
