@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017,2019-2021,2023 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019-2021,2023,2025 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,17 +44,18 @@ public:
 class SyncClient
 {
 public:
+  typedef std::unordered_map<Glib::ustring, Glib::ustring, Hash<Glib::ustring>> DeletedTitlesMap;
   virtual ~SyncClient();
 
-  virtual int last_synchronized_revision() = 0;
+  virtual int last_synchronized_revision() const = 0;
   virtual void last_synchronized_revision(int) = 0;
-  virtual Glib::DateTime last_sync_date() = 0;
+  virtual const Glib::DateTime &last_sync_date() const = 0;
   virtual void last_sync_date(const Glib::DateTime &) = 0;
-  virtual int get_revision(const NoteBase & note) = 0;
+  virtual int get_revision(const NoteBase &note) const = 0;
   virtual void set_revision(const NoteBase & note, int revision) = 0;
-  virtual std::map<Glib::ustring, Glib::ustring> deleted_note_titles() = 0;
+  virtual const DeletedTitlesMap &deleted_note_titles() const = 0;
   virtual void reset() = 0;
-  virtual Glib::ustring associated_server_id() = 0;
+  virtual const Glib::ustring &associated_server_id() const = 0;
   virtual void associated_server_id(const Glib::ustring &) = 0;
   virtual void begin_synchronization() = 0;
   virtual void end_synchronization() = 0;
@@ -68,7 +69,6 @@ public:
 
   virtual void reset_client() = 0;
   virtual void perform_synchronization(const SyncUI::Ptr & sync_ui) = 0;
-  virtual void resolve_conflict(SyncTitleConflictResolution resolution) = 0;
   virtual bool synchronized_note_xml_matches(const Glib::ustring & noteXml1, const Glib::ustring & noteXml2) = 0;
   virtual SyncState state() const = 0;
 };
@@ -76,13 +76,15 @@ public:
 class SyncServer
 {
 public:
+  typedef std::unordered_map<Glib::ustring, NoteUpdate, Hash<Glib::ustring>> NoteUpdatesMap;
+
   virtual ~SyncServer();
 
   virtual bool begin_sync_transaction() = 0;
   virtual bool commit_sync_transaction() = 0;
   virtual bool cancel_sync_transaction() = 0;
   virtual std::vector<Glib::ustring> get_all_note_uuids() = 0;
-  virtual std::map<Glib::ustring, NoteUpdate> get_note_updates_since(int revision) = 0;
+  virtual NoteUpdatesMap get_note_updates_since(int revision) = 0;
   virtual void delete_notes(const std::vector<Glib::ustring> & deletedNoteUUIDs) = 0;
   virtual void upload_notes(const std::vector<NoteBase::Ref> & notes) = 0;
   virtual int latest_revision() = 0; // NOTE: Only reliable during a transaction
